import datetime

from .report import send_to_slack


class TerminalText:
    def __init__(self, text):
        self._HEADER = '\033[95m'
        self._BLUE = '\033[94m'
        self._CYAN = '\033[96m'
        self._GREEN = '\033[92m'
        self._YELLOW = '\033[93m'
        self._FAIL = '\033[91m'
        self._END = '\033[0m'
        self._BOLD = '\033[1m'
        self._UNDERLINE = '\033[4m'
        self._TEXT = text
        self._DATETIME = f'{self._BLUE}**|**{self._END}{datetime.datetime.now()}{self._BLUE}**|**{self._END} '

    def header(self):
        """Print purple text """
        print(f'{self._DATETIME} {self._HEADER} - INFO - {self._TEXT} {self._END}')

    def tips(self):
        """Print blue text """
        print(f'{self._DATETIME} {self._GREEN} - TIPS - {self._END}{self._BLUE}{self._TEXT} \n{self._END}')

    def recommend(self):
        """Print cyan text """
        print(f'{self._DATETIME} {self._YELLOW} - RECOMMEND - {self._END}{self._CYAN}{self._TEXT}{self._END}')

    def info(self):
        """Print green text """
        print(f'{self._DATETIME} {self._GREEN} - INFO - {self._TEXT}{self._END}')

    def warning(self):
        """Print yellow text """
        print(f'{self._DATETIME} {self._YELLOW} - WARNING - {self._TEXT}{self._END}')

    def fail(self):
        """Print red text """
        print(f'{self._FAIL}"CRITICAL ==>"{self._END} \n{self._DATETIME} \n {self._FAIL}{self._TEXT}{self._END}')

    def text_error(self):
        """Print bold text """
        print(f'{self._DATETIME} {self._BOLD}{self._TEXT}{self._END}')

    def underline(self):
        """Print underline text """
        print(f'{self._DATETIME} {self._UNDERLINE}{self._TEXT}{self._END}')

    def report_to_slack(self, error):
        error_string = '`' + str(error) + '`'
        date = str(datetime.datetime.now())
        message = f'{date} \n*{self._TEXT}*'
        send_to_slack(message=message, error=error_string)
        text = 'An error was detected! \nThe bug results were sent to the developers, we will fix the problem and contact you shortly'
        print(f'{self._DATETIME} {self._GREEN}{text}{self._END}')

    def report_to_discord(self, error):
        """Report to discord server add later"""


if __name__ == '__main__':
    try:
        int('a')
    except ValueError as VA:
        TerminalText(
            'Тут буде опис проблеми від розробника, далі сама помилка:').report_to_slack(error=VA)



import os
from dotenv import load_dotenv
from slack import WebClient


class SlackMessenger:

    def __init__(self, message, error):
        load_dotenv()
        self.channel = os.getenv('SLACK_CHANEL')
        self.message = message
        self.error = error

        self.message_block = {
            "type": "section",
            "text": {
                "type": "mrkdwn",
                "text": (
                        self.message + '\n\n'
                ),
            },
        }

    def _prepare_message(self):
        error = {"type": "section", "text": {"type": "mrkdwn", "text": f"{self.error}"}}
        return error

    # Craft and return the entire message payload as a dictionary.
    def get_message_payload(self):
        error = self._prepare_message()
        return {
            "channel": self.channel,
            "blocks": [
                self.message_block,
                error,
            ],
        }


def send_to_slack(message, error):
    load_dotenv()

    # Create a slack client
    slack_web_client = WebClient(token=os.getenv("SLACK_TOKEN"))

    send_message = SlackMessenger(
        message=message,
        error=error
    )

    # Get the onboarding message payload
    message = send_message.get_message_payload()

    # Post the onboarding message in Slack
    slack_web_client.chat_postMessage(**message)


class DiscordServer:
    """This is a discord bot,
    he will be able to take message
    and send data for server.
    Communicate with the customer.
    Has a behavioral role roles.
    Need """


    def __init__(self):
        pass



from setuptools import setup, find_packages

setup(
    name='colordev',
    version='0.2.0',
    author='Oleg Bazaka',
    author_email='bazaka.developer@gmail.com',
    description='''Terminal Text package,
    which allows you to output text with different stylized colors in the terminal''',
    packages=find_packages(),
)
